@@ -36,9 +36,6 @@
 (eval-and-compile
   (require 'ef-themes)
 
-  ;; Most of the colors here are defined simply to preserve
-  ;; compatibility with the rest of the project.  We don't actually rely
-  ;; on them for anything critical.
 ;;;###theme-autoload
   (deftheme ef-duo-light
     "Legible light theme with mostly blue and yellow colors."
@@ -83,7 +80,7 @@
       (magenta-cooler  "#6052cf")
       (magenta-faint   "#af569f")
       (cyan            "#1f6fbf")
-      (cyan-warmer     "#3f6faf")
+      (cyan-warmer     "#3f70a0")
       (cyan-cooler     "#1f77bb")
       (cyan-faint      "#406f90")
 
@@ -188,7 +185,7 @@
 ;;;; Code mappings
 
       (builtin cyan-cooler)
-      (comment yellow-faint)
+      (comment red-faint)
       (constant blue)
       (fnname cyan)
       (keyword blue-warmer)
