@@ -71,10 +71,10 @@
       (yellow-warmer   "#b6532f")
       (yellow-cooler   "#b65050")
       (yellow-faint    "#a65f6a")
-      (blue            "#375cd8")
+      (blue            "#3740cf")
       (blue-warmer     "#4250ef")
       (blue-cooler     "#065fff")
-      (blue-faint      "#6060d0")
+      (blue-faint      "#4f54ba")
       (magenta         "#ba35af")
       (magenta-warmer  "#cf25aa")
       (magenta-cooler  "#6052cf")
@@ -189,7 +189,7 @@
       (constant blue-cooler)
       (fnname magenta-warmer)
       (keyword magenta-cooler)
-      (preprocessor red-warmer)
+      (preprocessor red)
       (docstring cyan-faint)
       (string blue-warmer)
       (type green-cooler)
@@ -308,7 +308,7 @@
 ;;;; Rainbow mappings
 
       (rainbow-0 green-cooler)
-      (rainbow-1 blue)
+      (rainbow-1 blue-faint)
       (rainbow-2 magenta-warmer)
       (rainbow-3 cyan-cooler)
       (rainbow-4 yellow-cooler)
