@@ -141,9 +141,9 @@
       (bg-hover-secondary "#493737")
       (bg-hl-line         "#002255")
       (bg-paren           "#664950")
-      (bg-err             "#331419") ; check with err
-      (bg-warning         "#332613") ; check with warning
-      (bg-info            "#002e1f") ; check with info
+      (bg-err             "#471014") ; check with err
+      (bg-warning         "#3b2f04") ; check with warning
+      (bg-info            "#103512") ; check with info
 
       (border        "#3a4a66")
       (cursor        "#00ccff")
@@ -179,7 +179,7 @@
       (identifier magenta-faint)
       (prompt cyan-warmer)
 
-      (bg-region "#222f40")
+      (bg-region "#253146")
       (fg-region unspecified)
 
 ;;;; Code mappings
@@ -263,6 +263,48 @@
       (bg-tab-current  bg-main)
       (bg-tab-other    bg-active)
 
+;;;; Terminal mappings
+
+      (bg-term-black           "black")
+      (fg-term-black           "black")
+      (bg-term-black-bright    "gray35")
+      (fg-term-black-bright    "gray35")
+
+      (bg-term-red             red)
+      (fg-term-red             red)
+      (bg-term-red-bright      red-warmer)
+      (fg-term-red-bright      red-warmer)
+
+      (bg-term-green           green)
+      (fg-term-green           green)
+      (bg-term-green-bright    green-warmer)
+      (fg-term-green-bright    green-warmer)
+
+      (bg-term-yellow          yellow)
+      (fg-term-yellow          yellow)
+      (bg-term-yellow-bright   yellow-warmer)
+      (fg-term-yellow-bright   yellow-warmer)
+
+      (bg-term-blue            blue)
+      (fg-term-blue            blue)
+      (bg-term-blue-bright     blue-warmer)
+      (fg-term-blue-bright     blue-warmer)
+
+      (bg-term-magenta         magenta)
+      (fg-term-magenta         magenta)
+      (bg-term-magenta-bright  magenta-cooler)
+      (fg-term-magenta-bright  magenta-cooler)
+
+      (bg-term-cyan            cyan)
+      (fg-term-cyan            cyan)
+      (bg-term-cyan-bright     cyan-cooler)
+      (fg-term-cyan-bright     cyan-cooler)
+
+      (bg-term-white           "gray65")
+      (fg-term-white           "gray65")
+      (bg-term-white-bright    "white")
+      (fg-term-white-bright    "white")
+
 ;;;; Rainbow mappings
 
       (rainbow-0 cyan-warmer)
