@@ -141,9 +141,9 @@
       (bg-hover-secondary "#452f5f")
       (bg-hl-line         "#34223f")
       (bg-paren           "#2f605e")
-      (bg-err             "#3a0f06") ; check with err
-      (bg-warning         "#332910") ; check with warning
-      (bg-info            "#1f2c00") ; check with info
+      (bg-err             "#461018") ; check with err
+      (bg-warning         "#3a330f") ; check with warning
+      (bg-info            "#103515") ; check with info
 
       (border        "#605760")
       (cursor        "#ff99ff")
@@ -263,6 +263,48 @@
       (bg-tab-current  bg-main)
       (bg-tab-other    bg-active)
 
+;;;; Terminal mappings
+
+      (bg-term-black           "black")
+      (fg-term-black           "black")
+      (bg-term-black-bright    "gray35")
+      (fg-term-black-bright    "gray35")
+
+      (bg-term-red             red-cooler)
+      (fg-term-red             red-cooler)
+      (bg-term-red-bright      red-warmer)
+      (fg-term-red-bright      red-warmer)
+
+      (bg-term-green           green)
+      (fg-term-green           green)
+      (bg-term-green-bright    green-warmer)
+      (fg-term-green-bright    green-warmer)
+
+      (bg-term-yellow          yellow)
+      (fg-term-yellow          yellow)
+      (bg-term-yellow-bright   yellow-warmer)
+      (fg-term-yellow-bright   yellow-warmer)
+
+      (bg-term-blue            blue-warmer)
+      (fg-term-blue            blue-warmer)
+      (bg-term-blue-bright     blue-cooler)
+      (fg-term-blue-bright     blue-cooler)
+
+      (bg-term-magenta         magenta)
+      (fg-term-magenta         magenta)
+      (bg-term-magenta-bright  magenta-cooler)
+      (fg-term-magenta-bright  magenta-cooler)
+
+      (bg-term-cyan            cyan)
+      (fg-term-cyan            cyan)
+      (bg-term-cyan-bright     cyan-cooler)
+      (fg-term-cyan-bright     cyan-cooler)
+
+      (bg-term-white           "gray65")
+      (fg-term-white           "gray65")
+      (bg-term-white-bright    "white")
+      (fg-term-white-bright    "white")
+
 ;;;; Rainbow mappings
 
       (rainbow-0 magenta-warmer)
