@@ -78,7 +78,7 @@
       (blue-warmer     "#6a88ff")
       (blue-cooler     "#029fff")
       (blue-faint      "#6a84af")
-      (magenta         "#b2608f")
+      (magenta         "#b0648f")
       (magenta-warmer  "#c560aa")
       (magenta-cooler  "#a6699f")
       (magenta-faint   "#c590af")
@@ -144,9 +144,9 @@
       (bg-hover-secondary "#5e3e5b")
       (bg-hl-line         "#3f1515")
       (bg-paren           "#2f5f7a")
-      (bg-err             "#3a0f0f") ; check with err
-      (bg-warning         "#371430") ; check with warning
-      (bg-info            "#00253a") ; check with info
+      (bg-err             "#451212") ; check with err
+      (bg-warning         "#40173d") ; check with warning
+      (bg-info            "#00354f") ; check with info
 
       (border        "#555564")
       (cursor        "#fd3333")
@@ -172,7 +172,7 @@
       (fg-fringe unspecified)
 
       (err red-warmer)
-      (warning magenta)
+      (warning magenta-warmer)
       (info cyan)
 
       (link cyan)
@@ -182,7 +182,7 @@
       (identifier magenta-faint)
       (prompt cyan)
 
-      (bg-region "#202d3f")
+      (bg-region "#293140")
       (fg-region unspecified)
 
 ;;;; Code mappings
@@ -266,6 +266,48 @@
       (bg-tab-current  bg-main)
       (bg-tab-other    bg-active)
 
+;;;; Terminal mappings
+
+      (bg-term-black           "black")
+      (fg-term-black           "black")
+      (bg-term-black-bright    "gray35")
+      (fg-term-black-bright    "gray35")
+
+      (bg-term-red             red-cooler)
+      (fg-term-red             red-cooler)
+      (bg-term-red-bright      red-warmer)
+      (fg-term-red-bright      red-warmer)
+
+      (bg-term-green           green)
+      (fg-term-green           green)
+      (bg-term-green-bright    green-warmer)
+      (fg-term-green-bright    green-warmer)
+
+      (bg-term-yellow          yellow)
+      (fg-term-yellow          yellow)
+      (bg-term-yellow-bright   yellow-warmer)
+      (fg-term-yellow-bright   yellow-warmer)
+
+      (bg-term-blue            blue-warmer)
+      (fg-term-blue            blue-warmer)
+      (bg-term-blue-bright     blue-cooler)
+      (fg-term-blue-bright     blue-cooler)
+
+      (bg-term-magenta         magenta)
+      (fg-term-magenta         magenta)
+      (bg-term-magenta-bright  magenta-cooler)
+      (fg-term-magenta-bright  magenta-cooler)
+
+      (bg-term-cyan            cyan)
+      (fg-term-cyan            cyan)
+      (bg-term-cyan-bright     cyan-cooler)
+      (fg-term-cyan-bright     cyan-cooler)
+
+      (bg-term-white           "gray65")
+      (fg-term-white           "gray65")
+      (bg-term-white-bright    "white")
+      (fg-term-white-bright    "white")
+
 ;;;; Rainbow mappings
 
       (rainbow-0 cyan)
